@@ -38,15 +38,17 @@
 #'   \code{data} object} \item{PANEL}{all distinct values in PANEL as passed in
 #'   \code{data} object} }
 #'
+#' @return A plot layer instance. Mainly used for the side-effect of printing
+#'   to the console the \code{data} object.
+#'
 #' @examples
-#' library(ggplot2)
 #' my.df <- data.frame(x = rep(1:10, 2),
 #'                     y = rep(c(1,2), c(10,10)),
 #'                     group = rep(c("A","B"), c(10,10)))
 #'
 #' ggplot(my.df, aes(x,y)) +
 #'   geom_point() +
-#'   stat_debug_group()
+#'   stat_debug_group(summary.fun = NULL)
 #'
 #' ggplot(my.df, aes(x,y, colour = group)) +
 #'   geom_point() +
@@ -61,13 +63,24 @@
 #' @family diagnosis functions
 #'
 stat_debug_group <-
-  function(mapping = NULL, data = NULL, geom = "null",
-           summary.fun = tibble::as_tibble, summary.fun.args = list(),
-           position = "identity", na.rm = FALSE, show.legend = FALSE,
-           inherit.aes = TRUE, ...) {
+  function(mapping = NULL,
+           data = NULL,
+           geom = "debug",
+           summary.fun = head,
+           summary.fun.args = list(),
+           position = "identity",
+           na.rm = FALSE,
+           show.legend = FALSE,
+           inherit.aes = TRUE,
+           ...) {
     ggplot2::layer(
-      stat = StatDebugGroup, data = data, mapping = mapping, geom = geom,
-      position = position, show.legend = show.legend, inherit.aes = inherit.aes,
+      stat = StatDebugGroup,
+      data = data,
+      mapping = mapping,
+      geom = geom,
+      position = position,
+      show.legend = show.legend,
+      inherit.aes = inherit.aes,
       params = list(na.rm = na.rm,
                     summary.fun = summary.fun,
                     summary.fun.args = summary.fun.args,
@@ -83,33 +96,28 @@ StatDebugGroup <-
   ggplot2::ggproto(
     "StatDebugGroup",
     ggplot2::Stat,
-    compute_group = function(data, scales, summary.fun, summary.fun.args) {
-      force(data)
+    compute_group = function(data,
+                             scales,
+                             summary.fun = head,
+                             summary.fun.args = list()) {
       if (!is.null(summary.fun)) {
-        data.summary <-  do.call(summary.fun, c(quote(data), summary.fun.args))
-        print("Input 'data' to 'compute_group()':")
-        print(data.summary)
+        z <-  do.call(summary.fun, c(quote(data), summary.fun.args))
+      } else {
+        z <- data
       }
-      my.diagnostic <-
-        data.frame(x = mean(range(data$x)),
-                   y = mean(range(data$y)),
-                   nrow = nrow(data),
-                   ncol = ncol(data),
-                   colnames = paste(colnames(data), collapse = ", "),
-                   colclasses = paste("x: ", class(data$x),
-                                      "; y: ",  class(data$y),
-                                      collapse = ", ", sep = ""),
-                   group = paste(unique(data$group), sep = ", "),
-                   PANEL = paste(unique(data$PANEL), sep = ", "))
-      my.diagnostic
+      cat("Input 'data' to 'compute_group()':\n")
+      print(z)
+      if (is.data.frame(z) && nrow(data) > nrow(z)) {
+        cat("...\n")
+      }
+      cat("\n")
+      tibble::tibble(x = mean(range(data$x)),
+                     y = mean(range(data$y)),
+                     nrow = nrow(data),
+                     ncol = ncol(data),
+                     colnames = list(colnames(data)),
+                     class.x = class(data$x),
+                     class.y = class(data$y))
     },
-    default_aes = ggplot2::aes(label = paste("group: ", stat(group), "; ",
-                                             "PANEL: ", stat(PANEL), "\n",
-                                             "nrow: ", stat(nrow), "; ",
-                                             "ncol: ", stat(ncol), "\n",
-                                             "cols: ", stat(colnames), "\n",
-                                             "classes: ", stat(colclasses),
-                                             sep = "")
-    ),
     required_aes = c("x", "y")
   )
